# About

A very niche project, but if you own and use the Garmin Approach R10, your range data (the Garmin Range) is available for download.  This is relevant because you have access to the metrics collected for each shot by the device, which is likely the same data used by other integrated apps like Awesome Golf and E6.

To me, this is important because it highlights the capabilities of the device, and for those of us nerds that like to dive into data, this represents an amazing plagyround.

## Ambitions

- Simply request your data, save it to your machine, and point the library at the downloaded file.
- Club stats and visualizations around each.
- ....

## Environment Help

- pyenv virtualenv
- pyenv local
- pyenv activate
- pyenv deactivate

> I think?  Converting to pyenv from conda so still feeling my way through runtimes and local projects that don't collide.



